@@ -27,7 +27,6 @@ class DnsimpleProviderTests(TestCase, IntegrationTests):
     def _filter_headers(self):
         return ['Authorization','set-cookie','X-Dnsimple-OTP']
 
-    # TODO: this should be enabled
-    @pytest.mark.skip(reason="regenerating auth keys required")
+    @pytest.mark.skip(reason="new test, missing recording")
     def test_Provider_when_calling_update_record_should_modify_record_name_specified(self):
         return
\ No newline at end of file
